==> thoth-report-processing-0.2.2.tar.gz: thoth-report-processing-0.2.2/CHANGELOG.md <==
# Changelog for Thoth's Template GitHub Project

## [0.1.0] - 2019-Sep-11 - goern

### Added

all the things that you see...

## Release 0.0.3 (2020-06-25T13:45:47)
* add filter files to docstring
* add ability to filter files
* Adjust link
* Remove self and use Python
* Add example
* Adjust README
* :pushpin: Automatic update of dependency thoth-storages from 0.23.2 to 0.24.0
* Introduce method to retrieve json aggregated
* Add sesheta to contributors
* Add missing import
* Correct docstring
* Add tests and exceptions for SIAggregator class
* Add SI aggregator class
* Update README
* Adjust mypi
* Add enums for store and exceptions
* Make coala and pre-commit happy
* small changes
* Add tests
* Add method
* Add import
* Divide classes
* Remove thoth-python
* Add setup.py
* Remove not necessary files
* Add security ouputs class
* Add requirements
* Add README
* update codeowners
* :arrow_up: updated standard configs, little bit of reformatting
* :sparkles: added a default OWNERS file, dont forget to adjust it!!

## Release 0.1.0 (2020-07-08T19:23:14)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.0 to 0.24.2 (#14)
* Added json to report from Qeb-hwt (#12)
* Update OWNERS

## Release 0.2.0 (2020-07-22T14:58:18)
* Add new adviser methods to Adviser class (#17)
* Update security reports processing (#11)

## Release 0.2.1 (2020-07-24T14:36:16)
* Adjust methods (#20)

## Release 0.2.2 (2020-07-24T16:35:57)
* Add missing packages to requirements.txt (#26)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.4 to 0.24.5 (#25)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.4 to 0.24.5 (#24)

==> thoth-report-processing-0.2.4.tar.gz: thoth-report-processing-0.2.4/CHANGELOG.md <==
# Changelog for Thoth's Template GitHub Project

## [0.1.0] - 2019-Sep-11 - goern

### Added

all the things that you see...

## Release 0.0.3 (2020-06-25T13:45:47)
* add filter files to docstring
* add ability to filter files
* Adjust link
* Remove self and use Python
* Add example
* Adjust README
* :pushpin: Automatic update of dependency thoth-storages from 0.23.2 to 0.24.0
* Introduce method to retrieve json aggregated
* Add sesheta to contributors
* Add missing import
* Correct docstring
* Add tests and exceptions for SIAggregator class
* Add SI aggregator class
* Update README
* Adjust mypi
* Add enums for store and exceptions
* Make coala and pre-commit happy
* small changes
* Add tests
* Add method
* Add import
* Divide classes
* Remove thoth-python
* Add setup.py
* Remove not necessary files
* Add security ouputs class
* Add requirements
* Add README
* update codeowners
* :arrow_up: updated standard configs, little bit of reformatting
* :sparkles: added a default OWNERS file, dont forget to adjust it!!

## Release 0.1.0 (2020-07-08T19:23:14)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.0 to 0.24.2 (#14)
* Added json to report from Qeb-hwt (#12)
* Update OWNERS

## Release 0.2.0 (2020-07-22T14:58:18)
* Add new adviser methods to Adviser class (#17)
* Update security reports processing (#11)

## Release 0.2.1 (2020-07-24T14:36:16)
* Adjust methods (#20)

## Release 0.2.2 (2020-07-24T16:35:57)
* Add missing packages to requirements.txt (#26)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.4 to 0.24.5 (#25)
* :pushpin: Automatic update of dependency thoth-storages from 0.24.4 to 0.24.5 (#24)

## Release 0.2.3 (2020-08-07T16:42:15)
* Add Inspection class (#31)
* :pushpin: Automatic update of dependency pandas from 1.0.5 to 1.1.0 (#30)
* python script name changed and therefore metadata (#29)

## Release 0.2.4 (2020-08-10T10:48:58)
* Adjust range for daily analysis (#34)
